@@ -12,12 +12,15 @@ class MyForm(QtGui.QMainWindow):
 		self.ui.setupUi(self)
 		# Create button actions
 		self.running = False
+		# Send Messages Button
 		QtCore.QObject.connect(self.ui.btnSendMessages, QtCore.SIGNAL('clicked()'), self.queueMessages)
 		self.maintimer = QtCore.QTimer(self);
 		self.connect(self.maintimer, QtCore.SIGNAL('timeout()'), self.processMessages)
+		# Changed index (combobox) action - hide flashsms checkbox
+		QtCore.QObject.connect(self.ui.cmbAccount, QtCore.SIGNAL("currentIndexChanged(QString)"), self.cmbAccountChange)
 		# Add items to the combo box.
 		#self.cmbAccount=QComboBox(FALSE, row1)
-		self.ui.cmbAccount.addItems(["Google Voice - QGVDial", "SIM"])
+		self.ui.cmbAccount.addItems(["SIM", "Google Voice - QGVDial"])
 		
 	def queueMessages(self):
 		if self.running:
@@ -36,6 +39,7 @@ class MyForm(QtGui.QMainWindow):
 			self.delay = int(self.ui.txtDelay.text())
 			self.repetitions = int(self.ui.txtRepetitions.text())
 			self.method = self.ui.cmbAccount.currentIndex()
+			self.flashSMS = self.ui.cbxFlashSMS.isChecked()
 			if self.repetitions >= 1:
 				self.sendMessage(self.method)
 			if self.repetitions > 1:
@@ -60,15 +64,24 @@ class MyForm(QtGui.QMainWindow):
 		
 	def sendMessage(self, method):
 		"""Send message using defined method (GV, SMS, etc)"""
-		if method == 0: # Google Voice
+		if method == 0: # SIM
+			if self.flashSMS:
+				os.system('/usr/bin/smssend -f -s -n ' + self.number + ' -m "' + self.message + '"')
+			else:
+				os.system('sudo /usr/bin/python /opt/smsbomb/smsMsg.py ' + self.number + '"' + self.message + '"')
+		elif method == 1: # Google Voice
 			# Import to use proper python sending technique
 			os.system('dbus-send --dest=org.QGVDial.TextServer --session --print-reply /org/QGVDial/TextServer org.QGVDial.TextServer.Text array:string:"' + self.number + '" string:"' + self.message + '"')
-		elif method == 1: # SIM
-			os.system('/usr/bin/smssend -s -n ' + self.number + ' -m "' + self.message + '"')
-			#print "SIM message sending not yet supported."
 		else:
 			print "Message sending method not recognized."
 		
+	def cmbAccountChange(self):
+		"""Hide or re-enable flashsms textbox when depending on choice"""
+		if self.ui.cmbAccount.currentIndex() == 0: # SIM
+			self.ui.cbxFlashSMS.show()
+		else:
+			self.ui.cbxFlashSMS.hide()
+		
 if __name__ == "__main__":
 	app = QtGui.QApplication(sys.argv)
 	myapp = MyForm()
